from eolymp.printer import printer_pb2 as _printer_pb2
from eolymp.printer import printer_job_pb2 as _printer_job_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PrinterConnectorClientMessage(_message.Message):
    __slots__ = ["id", "authenticate", "status", "report"]
    class Authenticate(_message.Message):
        __slots__ = ["secret"]
        SECRET_FIELD_NUMBER: _ClassVar[int]
        secret: str
        def __init__(self, secret: _Optional[str] = ...) -> None: ...
    class Report(_message.Message):
        __slots__ = ["status"]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        status: _printer_job_pb2.Job.Status
        def __init__(self, status: _Optional[_Union[_printer_job_pb2.Job.Status, str]] = ...) -> None: ...
    class Status(_message.Message):
        __slots__ = ["status"]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        status: _printer_pb2.Printer.Status
        def __init__(self, status: _Optional[_Union[_printer_pb2.Printer.Status, str]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    REPORT_FIELD_NUMBER: _ClassVar[int]
    id: str
    authenticate: PrinterConnectorClientMessage.Authenticate
    status: PrinterConnectorClientMessage.Status
    report: PrinterConnectorClientMessage.Report
    def __init__(self, id: _Optional[str] = ..., authenticate: _Optional[_Union[PrinterConnectorClientMessage.Authenticate, _Mapping]] = ..., status: _Optional[_Union[PrinterConnectorClientMessage.Status, _Mapping]] = ..., report: _Optional[_Union[PrinterConnectorClientMessage.Report, _Mapping]] = ...) -> None: ...

class PrinterConnectorServerMessage(_message.Message):
    __slots__ = ["id", "hello", "print"]
    class Hello(_message.Message):
        __slots__ = ["comment"]
        COMMENT_FIELD_NUMBER: _ClassVar[int]
        comment: str
        def __init__(self, comment: _Optional[str] = ...) -> None: ...
    class Print(_message.Message):
        __slots__ = ["job"]
        JOB_FIELD_NUMBER: _ClassVar[int]
        job: _printer_job_pb2.Job
        def __init__(self, job: _Optional[_Union[_printer_job_pb2.Job, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    HELLO_FIELD_NUMBER: _ClassVar[int]
    PRINT_FIELD_NUMBER: _ClassVar[int]
    id: str
    hello: PrinterConnectorServerMessage.Hello
    print: PrinterConnectorServerMessage.Print
    def __init__(self, id: _Optional[str] = ..., hello: _Optional[_Union[PrinterConnectorServerMessage.Hello, _Mapping]] = ..., print: _Optional[_Union[PrinterConnectorServerMessage.Print, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/printer/printer_job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/printer/printer_job.proto\x12\x0e\x65olymp.printer\"\xe5\x01\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.eolymp.printer.Job.Status\x12\x11\n\x07user_id\x18\n \x01(\tH\x00\x12\x13\n\tmember_id\x18\x0b \x01(\tH\x00\x12\x14\n\x0c\x64ocument_url\x18\x14 \x01(\t\"]\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08PRINTING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0b\n\x07\x45XPIRED\x10\x05\x42\t\n\x07\x63reatorB1Z/github.com/eolymp/go-sdk/eolymp/printer;printerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.printer.printer_job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/printer;printer'
  _globals['_JOB']._serialized_start=53
  _globals['_JOB']._serialized_end=282
  _globals['_JOB_STATUS']._serialized_start=178
  _globals['_JOB_STATUS']._serialized_end=271
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PrintCodeInput(_message.Message):
    __slots__ = ["source"]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    source: str
    def __init__(self, source: _Optional[str] = ...) -> None: ...

class PrintCodeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.executor import checker_pb2 as _checker_pb2
from eolymp.executor import file_pb2 as _file_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Checker(_message.Message):
    __slots__ = ["type", "runtime", "source", "precision", "case_sensitive", "order_sensitive", "secret", "files"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    CASE_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    ORDER_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    type: _checker_pb2.Checker.Type
    runtime: str
    source: str
    precision: int
    case_sensitive: bool
    order_sensitive: bool
    secret: bool
    files: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    def __init__(self, type: _Optional[_Union[_checker_pb2.Checker.Type, str]] = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., precision: _Optional[int] = ..., case_sensitive: bool = ..., order_sensitive: bool = ..., secret: bool = ..., files: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/code_template.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/atlas/code_template.proto\x12\x0c\x65olymp.atlas\x1a\x1a\x65olymp/executor/file.proto\"\x8d\x01\n\x08Template\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\x08\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0e\n\x06header\x18\x0b \x01(\t\x12\x0e\n\x06\x66ooter\x18\x0c \x01(\t\x12$\n\x05\x66iles\x18\x1e \x03(\x0b\x32\x15.eolymp.executor.FileB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.code_template_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_TEMPLATE']._serialized_start=79
  _globals['_TEMPLATE']._serialized_end=220
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/scoring_score.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/atlas/scoring_score.proto\x12\x0c\x65olymp.atlas\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x01\n\x05Score\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x07 \x01(\t\x12-\n\tsolved_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05score\x18\x05 \x01(\x02\x12\x10\n\x08\x61ttempts\x18\x08 \x01(\rB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.scoring_score_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SCORE']._serialized_start=84
  _globals['_SCORE']._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_interactor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2
from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/atlas/testing_interactor.proto\x12\x0c\x65olymp.atlas\x1a\x1a\x65olymp/executor/file.proto\x1a eolymp/executor/interactor.proto\"\x93\x01\n\nInteractor\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .eolymp.executor.Interactor.Type\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x08 \x01(\t\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12$\n\x05\x66iles\x18\n \x03(\x0b\x32\x15.eolymp.executor.FileB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_interactor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_INTERACTOR']._serialized_start=118
  _globals['_INTERACTOR']._serialized_end=265
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/printer/printer_connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.printer import printer_pb2 as eolymp_dot_printer_dot_printer__pb2
from eolymp.printer import printer_job_pb2 as eolymp_dot_printer_dot_printer__job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/printer/printer_connector.proto\x12\x0e\x65olymp.printer\x1a\x1c\x65olymp/printer/printer.proto\x1a eolymp/printer/printer_job.proto\"\xaa\x03\n\x1dPrinterConnectorClientMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12R\n\x0c\x61uthenticate\x18\x64 \x01(\x0b\x32:.eolymp.printer.PrinterConnectorClientMessage.AuthenticateH\x00\x12\x46\n\x06status\x18\x65 \x01(\x0b\x32\x34.eolymp.printer.PrinterConnectorClientMessage.StatusH\x00\x12\x46\n\x06report\x18\x66 \x01(\x0b\x32\x34.eolymp.printer.PrinterConnectorClientMessage.ReportH\x00\x1a\x1e\n\x0c\x41uthenticate\x12\x0e\n\x06secret\x18\x01 \x01(\t\x1a\x34\n\x06Report\x12*\n\x06status\x18\x01 \x01(\x0e\x32\x1a.eolymp.printer.Job.Status\x1a\x38\n\x06Status\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.eolymp.printer.Printer.StatusB\t\n\x07message\"\x87\x02\n\x1dPrinterConnectorServerMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x44\n\x05hello\x18\x64 \x01(\x0b\x32\x33.eolymp.printer.PrinterConnectorServerMessage.HelloH\x00\x12\x44\n\x05print\x18n \x01(\x0b\x32\x33.eolymp.printer.PrinterConnectorServerMessage.PrintH\x00\x1a\x18\n\x05Hello\x12\x0f\n\x07\x63omment\x18\x01 \x01(\t\x1a)\n\x05Print\x12 \n\x03job\x18\x01 \x01(\x0b\x32\x13.eolymp.printer.JobB\t\n\x07message2\x81\x01\n\x10PrinterConnector\x12m\n\x07\x43onnect\x12-.eolymp.printer.PrinterConnectorClientMessage\x1a-.eolymp.printer.PrinterConnectorServerMessage\"\x00(\x01\x30\x01\x42\x31Z/github.com/eolymp/go-sdk/eolymp/printer;printerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.printer.printer_connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/printer;printer'
  _globals['_PRINTERCONNECTORCLIENTMESSAGE']._serialized_start=123
  _globals['_PRINTERCONNECTORCLIENTMESSAGE']._serialized_end=549
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_AUTHENTICATE']._serialized_start=396
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_AUTHENTICATE']._serialized_end=426
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_REPORT']._serialized_start=428
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_REPORT']._serialized_end=480
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_STATUS']._serialized_start=482
  _globals['_PRINTERCONNECTORCLIENTMESSAGE_STATUS']._serialized_end=538
  _globals['_PRINTERCONNECTORSERVERMESSAGE']._serialized_start=552
  _globals['_PRINTERCONNECTORSERVERMESSAGE']._serialized_end=815
  _globals['_PRINTERCONNECTORSERVERMESSAGE_HELLO']._serialized_start=737
  _globals['_PRINTERCONNECTORSERVERMESSAGE_HELLO']._serialized_end=761
  _globals['_PRINTERCONNECTORSERVERMESSAGE_PRINT']._serialized_start=763
  _globals['_PRINTERCONNECTORSERVERMESSAGE_PRINT']._serialized_end=804
  _globals['_PRINTERCONNECTOR']._serialized_start=818
  _globals['_PRINTERCONNECTOR']._serialized_end=947
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/editor_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/atlas/editor_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\" \n\x0ePrintCodeInput\x12\x0e\n\x06source\x18\x01 \x01(\t\"\x11\n\x0fPrintCodeOutput2\x9e\x01\n\rEditorService\x12\x8c\x01\n\tPrintCode\x12\x1c.eolymp.atlas.PrintCodeInput\x1a\x1d.eolymp.atlas.PrintCodeOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02\x0f\"\r/editor:printB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.editor_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_EDITORSERVICE'].methods_by_name['PrintCode']._options = None
  _globals['_EDITORSERVICE'].methods_by_name['PrintCode']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002\017\"\r/editor:print'
  _globals['_PRINTCODEINPUT']._serialized_start=150
  _globals['_PRINTCODEINPUT']._serialized_end=182
  _globals['_PRINTCODEOUTPUT']._serialized_start=184
  _globals['_PRINTCODEOUTPUT']._serialized_end=201
  _globals['_EDITORSERVICE']._serialized_start=204
  _globals['_EDITORSERVICE']._serialized_end=362
# @@protoc_insertion_point(module_scope)
